@@ -2,23 +2,25 @@
 # This file is part of AceQL Python Client SDK.
 # AceQL Python Client SDK: Remote SQL access over HTTP with AceQL HTTP.
 # Copyright (C) 2020,  KawanSoft SAS
-# (http://www.kawansoft.com). All rights reserved.                                
-#                                                                               
+# (http://www.kawansoft.com). All rights reserved.
+#
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
 # You may obtain a copy of the License at
-# 
+#
 #     http://www.apache.org/licenses/LICENSE-2.0
-# 
+#
 # Unless required by applicable law or agreed to in writing, software
 # distributed under the License is distributed on an "AS IS" BASIS,
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
-# limitations under the License. 
+# limitations under the License.
 ##
 
-from aceql._private.row_parser import *
-from aceql._private.aceql_http_api import *
+from aceql._private.row_parser import RowParser
+from aceql._private.cursor_util import CursorUtil
+from aceql._private.datetime_util import DateTimeUtil
+from aceql._private.aceql_http_api import AceQLDebug, Error, os
 
 
 class Cursor(object):
@@ -156,6 +158,7 @@ class Cursor(object):
         values_per_column_index = self.__row_parser.get_values_per_col_index()
         types_per_column_index = self.__row_parser.get_types_per_col_index()
 
+        from aceql import Parms
         if Parms.DEBUG_ON:
             print("values_per_column_index: " + str(values_per_column_index))
             print("types_per_column_index : " + str(types_per_column_index))
@@ -163,7 +166,8 @@ class Cursor(object):
         the_list = []
         index = 0
         for k, v in values_per_column_index.items():
-            # print(k, v)
+            if Parms.DEBUG_ON:
+                print(k, v)
             # detect Epoch timestamp and convert them to date for DATE and datetime for
             # TIMESTAMP
             if types_per_column_index[index] == "TIMESTAMP":
@@ -268,8 +272,8 @@ class Cursor(object):
             while index < len(aceql_types):
                 name_and_type = list()
 
-                #name_and_type.append(aceql_names[index])
-                #name_and_type.append(aceql_types[index])
+                # name_and_type.append(aceql_names[index])
+                # name_and_type.append(aceql_types[index])
 
                 aceql_name = aceql_names.get(index)
                 if aceql_name is not None:
@@ -292,6 +296,17 @@ class Cursor(object):
             if row_parser is not None:
                 row_parser.close()
 
+    @staticmethod
+    def check_blob_id(blob_id, column_index):
+        """Checks blob id"""
+        if blob_id is None:
+            raise Error("No value found for column_index " + str(column_index),
+                        0, None, None, 200)
+
+        if not blob_id.endswith(".blob"):
+            raise Error("Fetched value does not correspond to a BLOB Id: " + str(blob_id),
+                        0, None, None, 200)
+
     # def blob_download(self, blob_id, filename, total_length=0,
     # progress_holder=None):
     # 	""" Allows to download a blob corresponding to a blob_id into a filename
@@ -332,14 +347,7 @@ class Cursor(object):
 
         print("blob_id: " + str(blob_id))
 
-        if blob_id is None:
-            raise Error("No value found for column_index " + str(column_index),
-                        0, None, None, 200)
-
-        if not blob_id.endswith(".blob"):
-            raise Error("Fetched value does not correspond to a BLOB Id: " + str(blob_id),
-                        0, None, None, 200)
-
+        Cursor.check_blob_id(blob_id, column_index)
         blob_length = self.__aceql_http_api.get_blob_length(blob_id)
         return blob_length
 
@@ -362,13 +370,7 @@ class Cursor(object):
 
         blob_id = values_per_column_index[column_index]
 
-        if blob_id is None:
-            raise Error("No value found for column_index " + str(column_index),
-                        0, None, None, 200)
-
-        if not blob_id.endswith(".blob"):
-            raise Error("Fetched value does not correspond to a BLOB Id: " + str(blob_id),
-                        0, None, None, 200)
+        Cursor.check_blob_id(blob_id, column_index)
 
         # OK!  we have a valid BLOB Id:
         response = self.__aceql_http_api.get_blob_stream(blob_id)
@@ -385,10 +387,11 @@ class Cursor(object):
         if self.__row_parser is not None:
             self.__row_parser.close()  # very important
 
+        from aceql import Parms
         if Parms.DELETE_FILES:
             for filename in self.__filelist:
                 os.remove(filename)
 
     def __raise_error_if_closed(self):
         if self.__is_closed:
-            raise Error("Invalid call: Cursor is closed.", 0, None, None, 200)
\ No newline at end of file
+            raise Error("Invalid call: Cursor is closed.", 0, None, None, 200)
